@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef MOCK_DECORATION_H
-#define MOCK_DECORATION_H
+#pragma once
 
 #include "../src/decoration.h"
 
@@ -23,5 +22,3 @@ public:
     using Decoration::setTitleBar;
     void setTitleBar(const QRect &rect);
 };
-
-#endif
